@@ -2,7 +2,7 @@ from recruiter_app.elt_app.collections.evaluate_candidates import EvalCandidates
 from recruiter_app.utilities.helpers import mongo_global_init
 from recruiter_notification_app.recruiter_app_mailer import MailService
 
-from flask import Flask, render_template, request
+from flask import Flask, render_template, request, jsonify
 from flask_mail import Mail
 from itsdangerous import URLSafeTimedSerializer, SignatureExpired
 import os
@@ -33,8 +33,9 @@ def index():
     """
     print(f"Starting to notify candidates {request.args}")
     recipients = ['anamadheyaashoka005@gmail.com', 'anamadheyaashoka003@gmail.com']
-    candidate_id = request.args.get("candidate_id")
-    jd_name = request.args.get("jd_name")
+    req_dict = request.get_json(force=True)
+    candidate_id = req_dict.get("candidate_id")
+    jd_name = req_dict.get("jd_name")
     if candidate_id:
         print(f"request received for id : {candidate_id}")
         rand_mail_idx = random.randint(0, 1)
@@ -83,4 +84,4 @@ def home():
 
 
 def main():
-    app.run(host="0.0.0.0", debug=True)
+    app.run(host="0.0.0.0")
